'use strict';

var RoadieOpenAiAugmenter = require('./RoadieOpenAiAugmenter.cjs.js');

async function initializeOpenAiEmbeddings({
  logger,
  auth,
  vectorStore,
  catalogApi,
  discovery,
  config
}) {
  logger.info("Initializing Roadie OpenAI Embeddings");
  const openAiConfig = config.get("ai.embeddings.openai");
  const embeddingsOptions = config.getOptionalConfig("ai.embeddings");
  const augmentationOptions = {};
  if (embeddingsOptions) {
    augmentationOptions.chunkSize = embeddingsOptions.getOptionalNumber("chunkSize");
    augmentationOptions.chunkOverlap = embeddingsOptions.getOptionalNumber("chunkOverlap");
    augmentationOptions.concurrencyLimit = embeddingsOptions.getOptionalNumber("concurrencyLimit");
  }
  return new RoadieOpenAiAugmenter.RoadieOpenAiAugmenter({
    vectorStore,
    catalogApi,
    discovery,
    augmentationOptions,
    logger: logger.child({ label: "roadie-openai-embeddings" }),
    auth,
    config: openAiConfig
  });
}

exports.initializeOpenAiEmbeddings = initializeOpenAiEmbeddings;
//# sourceMappingURL=index.cjs.js.map
